@@ -1,6 +1,6 @@
-'Scrypt for Python'
+"""Scrypt for Python"""
 
-__version__ = '1.1.3'
+__version__ = '1.2.0'
 
 # First, try loading libscrypt
 _done = False
@@ -25,7 +25,7 @@ if not _done:
     import platform
     if platform.python_implementation() != 'PyPy':
         try:
-            from pylibsodium import *
+            from pylibsodium_salsa import *
         except ImportError:
             pass
         else:
@@ -48,5 +48,4 @@ __all__ = ['scrypt', 'scrypt_mcf', 'scrypt_mcf_check']
 
 # Clean up pydoc output
 del __path__
-del consts
 
