@@ -3,13 +3,13 @@
 
 import time
 
-from consts import *
+from common import *
 from pylibscrypt import scrypt
 from pypyscrypt_inline import scrypt as pyscrypt
-from pylibsodium import scrypt as pcscrypt
+from pylibsodium_salsa import scrypt as pcscrypt
 
 
-# Benchmark time in seconds 
+# Benchmark time in seconds
 tmin = 5
 Nmax = 20
 
