@@ -27,9 +27,8 @@ import base64
 import ctypes, ctypes.util
 from ctypes import c_char_p, c_size_t, c_uint64, c_uint32
 import os
-import numbers
 
-from consts import *
+from common import *
 import mcf as mcf_mod
 
 
@@ -93,24 +92,7 @@ def scrypt(password, salt, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p, olen=64):
     key derivation is not a problem, you could use 16 as in libscrypt or better
     yet increase N if memory is plentiful.
     """
-    if not isinstance(password, bytes):
-        raise TypeError('password must be a byte string')
-    if not isinstance(salt, bytes):
-        raise TypeError('salt must be a byte string')
-    if not isinstance(N, numbers.Integral):
-        raise TypeError('N must be an integer')
-    if not isinstance(r, numbers.Integral):
-        raise TypeError('r must be an integer')
-    if not isinstance(p, numbers.Integral):
-        raise TypeError('p must be an integer')
-    if N > 2**63:
-        raise ValueError('N value cannot be larger than 2**63')
-    if N < 2:
-        raise ValueError('N must be a power of two larger than 1')
-    if r <= 0 or p <= 0:
-        raise ValueError('r and p must be positive')
-    if r * p >= 2**30:
-        raise ValueError('r * p >= 2 ** 30')
+    check_args(password, salt, N, r, p, olen)
 
     out = ctypes.create_string_buffer(olen)
     ret = _libscrypt_scrypt(password, len(password), salt, len(salt),
@@ -121,7 +103,8 @@ def scrypt(password, salt, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p, olen=64):
     return out.raw
 
 
-def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p):
+def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p,
+               prefix=SCRYPT_MCF_PREFIX_DEFAULT):
     """Derives a Modular Crypt Format hash using the scrypt KDF
 
     Parameter space is smaller than for scrypt():
@@ -129,8 +112,10 @@ def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p):
     r and p must be positive numbers between 1 and 255
     Salt must be a byte string 1-16 bytes long.
 
-    If no salt is given, 16 random bytes are generated using os.urandom.
+    If no salt is given, a random salt of 128+ bits is used. (Recommended.)
     """
+    if (prefix != SCRYPT_MCF_PREFIX_s1 and prefix != SCRYPT_MCF_PREFIX_ANY):
+        return mcf_mod.scrypt_mcf(scrypt, password, salt, N, r, p, prefix)
     if salt is None:
         salt = os.urandom(16)
     elif not (1 <= len(salt) <= 16):
@@ -145,7 +130,7 @@ def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p):
     h64 = base64.b64encode(hash)
     s64 = base64.b64encode(salt)
 
-    out = ctypes.create_string_buffer(SCRYPT_MCF_LEN)
+    out = ctypes.create_string_buffer(125)
     ret = _libscrypt_mcf(N, r, p, s64, h64, out)
     if not ret:
         raise ValueError
@@ -170,7 +155,7 @@ def scrypt_mcf_check(mcf, password):
     mcfbuf = ctypes.create_string_buffer(mcf)
     ret = _libscrypt_check(mcfbuf, password)
     if ret < 0:
-        raise ValueError
+        return mcf_mod.scrypt_mcf_check(scrypt, mcf, password)
 
     return bool(ret)
 
