@@ -35,11 +35,10 @@
 
 
 import hashlib, hmac
-import numbers
 import struct
 
 import mcf as mcf_mod
-from consts import *
+from common import *
 
 
 # Python 3.4+ have PBKDF2 in hashlib, so use it...
@@ -149,27 +148,7 @@ def scrypt(password, salt, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p, olen=64):
 
         array_overwrite(X, 0, B, Bi, 32 * r)               # ROMix - 10
 
-    if not isinstance(password, bytes):
-        raise TypeError('password must be a byte string')
-    if not isinstance(salt, bytes):
-        raise TypeError('salt must be a byte string')
-    if not isinstance(N, numbers.Integral):
-        raise TypeError('N must be an integer')
-    if not isinstance(r, numbers.Integral):
-        raise TypeError('r must be an integer')
-    if not isinstance(p, numbers.Integral):
-        raise TypeError('p must be an integer')
-
-    if N < 2 or (N & (N - 1)):
-        raise ValueError('scrypt N must be a power of 2 greater than 1')
-    if N > 2 ** 63:
-        raise ValueError('N value cannot be larger than 2**63')
-    if r <= 0:
-        raise ValueError('scrypt r must be positive')
-    if p <= 0:
-        raise ValueError('scrypt p must be positive')
-    if r * p >= 2**30:
-        raise ValueError('r * p >= 2 ** 30')
+    check_args(password, salt, N, r, p, olen)
 
     # Everything is lists of 32-bit uints for all but pbkdf2
     try:
@@ -187,7 +166,8 @@ def scrypt(password, salt, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p, olen=64):
     return _pbkdf2('sha256', password, B, 1, olen)
 
 
-def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p):
+def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p,
+               prefix=SCRYPT_MCF_PREFIX_DEFAULT):
     """Derives a Modular Crypt Format hash using the scrypt KDF
 
     Parameter space is smaller than for scrypt():
@@ -195,9 +175,9 @@ def scrypt_mcf(password, salt=None, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p):
     r and p must be positive numbers between 1 and 255
     Salt must be a byte string 1-16 bytes long.
 
-    If no salt is given, 16 random bytes are generated using os.urandom.
+    If no salt is given, a random salt of 128+ bits is used. (Recommended.)
     """
-    return mcf_mod.scrypt_mcf(scrypt, password, salt, N, r, p)
+    return mcf_mod.scrypt_mcf(scrypt, password, salt, N, r, p, prefix)
 
 
 def scrypt_mcf_check(mcf, password):
